@@ -28,8 +28,8 @@ sub load {
         $self->plugins->{$module}{code} = $module_function;
         $self->plugins->{$module}{name} = $module;
         $self->plugins->{$module}{data} = $opt{data};
-        $self->plugins->{$module}{priority} = $opt{priority} || 0;
-        $self->plugins->{$module}{auto_call} = 1 unless defined $opt{auto_call} ;
+        $self->plugins->{$module}{priority} = $opt{priority} || eval "\$${module}::PRIORITY" ||  0;
+        $self->plugins->{$module}{auto_call} = $opt{auto_call} || eval "\$${module}::AUTO_CALL" || 1 ;
         $self->emit("plugin_load",$module);
     }
 }
