@@ -1,4 +1,5 @@
 package Mojo::Webqq::Plugin::Perlcode;
+$Mojo::Webqq::Plugin::Perlcode::PRIORITY = 97;
 use File::Temp qw/tempfile/;
 use File::Path qw/mkpath rmtree/;
 use POSIX qw(strftime);
@@ -7,16 +8,18 @@ BEGIN{
     $Mojo::Webqq::Plugin::Perlcode::is_hold_bsd_resource = 1 unless $@; 
 }
 use Mojo::Webqq::Run;
+use Term::ANSIColor;
 my $run = Mojo::Webqq::Run->new;
 sub call{
     my $client = shift;
     $client->die(__PACKAGE__ . "只能运行在linux系统上") if $^O !~ /linux/; 
     $client->die(__PACKAGE__ . "依赖BSD::Resource模块，请先安装该模块") if !$Mojo::Webqq::Plugin::Perlcode::is_hold_bsd_resource; 
-    $client->on(receive_message=>sub{
+    my $callback = sub{
         my($client,$msg) = @_;
         return if not $msg->allow_plugin;
         if($msg->content=~/(?:>>>)(.*?)(?:__END__|$)/s or $msg->content =~/perl\s+-e\s+'([^']+)'/s){
             $msg->allow_plugin(0);
+            return if $msg->msg_class eq "send" and $msg->msg_from ne "api" and $msg->msg_from ne "irc";
             my $doc = '';
             my $code = $1;
             $code=~s/^\s+|\s+$//g;
@@ -56,14 +59,14 @@ sub call{
                 stderr_cb => sub {
                     my ($pid, $chunk) = @_;
                     $stderr_buf.=$chunk;
-                    if(length($stderr_buf) > 500){
+                    if(count_lines($stderr_buf) > 10){
                         $run->kill($pid);
-                        $stderr_buf = substr($stderr_buf,0,500);
+                        $stderr_buf  = join "\n",(split /\n/,$stderr_buf,11)[0..9];
                         $stderr_buf .= "(已截断)";
                     }
-                    elsif(count_lines($stderr_buf) > 10){
+                    elsif(length($stderr_buf) > 500){
                         $run->kill($pid);
-                        $stderr_buf  = join "\n",(split /\n/,$stdout_buf,11)[0..9];
+                        $stderr_buf = substr($stderr_buf,0,500);
                         $stderr_buf .= "(已截断)";
                     }
                 },
@@ -72,6 +75,10 @@ sub call{
                     my $content;
                     $stderr_buf =~s/(?<=at )\(eval .+?\)(?= line)/CODE/g;
                     $stderr_buf.= "(执行超时)" if $res->{stderr}=~/\Q;Execution timeout.\E$/;
+                    eval{
+                        $stderr_buf = Term::ANSIColor::colorstrip($stderr_buf);
+                        $stdout_buf = Term::ANSIColor::colorstrip($stdout_buf);
+                    };
                     if(defined $stdout_buf and defined $stderr_buf){
                         if($stdout_buf=~/\n$/){$content = $stdout_buf.$stderr_buf}
                         else{$content = $stdout_buf."\n".$stderr_buf}
@@ -83,7 +90,9 @@ sub call{
             );  
             #$run->start;
         }    
-    }); 
+    }; 
+    $client->on(receive_message=>$callback);
+    $client->on(send_message=>$callback);
 }
 
 sub count_lines{
